(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs/operators'), require('@angular/common/http'), require('@angular/platform-browser')) :
    typeof define === 'function' && define.amd ? define('angular-embed-video', ['exports', '@angular/core', 'rxjs/operators', '@angular/common/http', '@angular/platform-browser'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['angular-embed-video'] = {}, global.ng.core, global.rxjs.operators, global.ng.common.http, global.ng.platformBrowser));
}(this, (function (exports, i0, operators, i1, i2) { 'use strict';

    function _interopNamespace(e) {
        if (e && e.__esModule) return e;
        var n = Object.create(null);
        if (e) {
            Object.keys(e).forEach(function (k) {
                if (k !== 'default') {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () {
                            return e[k];
                        }
                    });
                }
            });
        }
        n['default'] = e;
        return Object.freeze(n);
    }

    var i0__namespace = /*#__PURE__*/_interopNamespace(i0);
    var i1__namespace = /*#__PURE__*/_interopNamespace(i1);
    var i2__namespace = /*#__PURE__*/_interopNamespace(i2);

    var AngularEmbedVideoService = /** @class */ (function () {
        function AngularEmbedVideoService(http, sanitizer) {
            this.http = http;
            this.sanitizer = sanitizer;
            this.validYouTubeOptions = [
                'default',
                'mqdefault',
                'hqdefault',
                'sddefault',
                'maxresdefault'
            ];
            this.validVimeoOptions = [
                'thumbnail_small',
                'thumbnail_medium',
                'thumbnail_large'
            ];
            this.validDailyMotionOptions = [
                'thumbnail_60_url',
                'thumbnail_120_url',
                'thumbnail_180_url',
                'thumbnail_240_url',
                'thumbnail_360_url',
                'thumbnail_480_url',
                'thumbnail_720_url',
                'thumbnail_1080_url'
            ];
        }
        AngularEmbedVideoService.prototype.embed = function (url, options) {
            var id;
            url = new URL(url);
            id = this.detectYoutube(url);
            if (id) {
                return this.embed_youtube(id, options);
            }
            id = this.detectVimeo(url);
            if (id) {
                return this.embed_vimeo(id, options);
            }
            id = this.detectDailymotion(url);
            if (id) {
                return this.embed_dailymotion(id, options);
            }
        };
        AngularEmbedVideoService.prototype.embed_youtube = function (id, options) {
            options = this.parseOptions(options);
            return this.sanitize_iframe('<iframe src="https://www.youtube.com/embed/'
                + id + options.query + '"' + options.attr
                + ' frameborder="0" allowfullscreen></iframe>');
        };
        AngularEmbedVideoService.prototype.embed_vimeo = function (id, options) {
            options = this.parseOptions(options);
            return this.sanitize_iframe('<iframe src="https://player.vimeo.com/video/'
                + id + options.query + '"' + options.attr
                + ' frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>');
        };
        AngularEmbedVideoService.prototype.embed_dailymotion = function (id, options) {
            options = this.parseOptions(options);
            return this.sanitize_iframe('<iframe src="https://www.dailymotion.com/embed/video/'
                + id + options.query + '"' + options.attr
                + ' frameborder="0" allowfullscreen></iframe>');
        };
        AngularEmbedVideoService.prototype.embed_image = function (url, options) {
            var id;
            url = new URL(url);
            id = this.detectYoutube(url);
            if (id) {
                return this.embed_youtube_image(id, options);
            }
            id = this.detectVimeo(url);
            if (id) {
                return this.embed_vimeo_image(id, options);
            }
            id = this.detectDailymotion(url);
            if (id) {
                return this.embed_dailymotion_image(id, options);
            }
        };
        AngularEmbedVideoService.prototype.embed_youtube_image = function (id, options) {
            if (typeof options === 'function') {
                options = {};
            }
            options = options || {};
            options.image = this.validYouTubeOptions.includes(options.image) ? options.image : 'default';
            var src = 'https://img.youtube.com/vi/' + id + '/' + options.image + '.jpg';
            var result = {
                link: src,
                html: '<img src="' + src + '"/>'
            };
            return Promise.resolve(result).then(function (value) { return value; });
        };
        AngularEmbedVideoService.prototype.embed_vimeo_image = function (id, options) {
            if (typeof options === 'function') {
                options = {};
            }
            options = options || {};
            options.image = this.validVimeoOptions.indexOf(options.image) >= 0 ? options.image : 'thumbnail_large';
            return this.http.get('https://vimeo.com/api/v2/video/' + id + '.json').pipe(operators.map(function (res) {
                return {
                    'link': res[0][options.image],
                    'html': '<img src="' + res[0][options.image] + '"/>'
                };
            }))
                .toPromise()
                .catch(function (error) { return console.log(error); });
        };
        AngularEmbedVideoService.prototype.embed_dailymotion_image = function (id, options) {
            if (typeof options === 'function') {
                options = {};
            }
            options = options || {};
            options.image = this.validDailyMotionOptions.indexOf(options.image) >= 0 ? options.image : 'thumbnail_480_url';
            return this.http.get('https://api.dailymotion.com/video/' + id + '?fields=' + options.image)
                .pipe(operators.map(function (res) {
                return {
                    'link': res[options.image],
                    'html': '<img src="' + res[options.image] + '"/>'
                };
            }))
                .toPromise()
                .catch(function (error) { return console.log(error); });
        };
        AngularEmbedVideoService.prototype.parseOptions = function (options) {
            var queryString = '', attributes = '';
            if (options && options.hasOwnProperty('query')) {
                queryString = '?' + this.serializeQuery(options.query);
            }
            if (options && options.hasOwnProperty('attr')) {
                var temp_1 = [];
                Object.keys(options.attr).forEach(function (key) {
                    temp_1.push(key + '="' + (options.attr[key]) + '"');
                });
                attributes = ' ' + temp_1.join(' ');
            }
            return {
                query: queryString,
                attr: attributes
            };
        };
        AngularEmbedVideoService.prototype.serializeQuery = function (query) {
            var queryString = [];
            for (var p in query) {
                if (query.hasOwnProperty(p)) {
                    queryString.push(encodeURIComponent(p) + '=' + encodeURIComponent(query[p]));
                }
            }
            return queryString.join('&');
        };
        AngularEmbedVideoService.prototype.sanitize_iframe = function (iframe) {
            return this.sanitizer.bypassSecurityTrustHtml(iframe);
        };
        AngularEmbedVideoService.prototype.detectVimeo = function (url) {
            return (url.hostname === 'vimeo.com') ? url.pathname.split('/')[1] : null;
        };
        AngularEmbedVideoService.prototype.detectYoutube = function (url) {
            if (url.hostname.indexOf('youtube.com') > -1) {
                var video_id = url.search.split('v=')[1];
                var ampersandPosition = video_id.indexOf('&');
                if (ampersandPosition != -1) {
                    video_id = video_id.substring(0, ampersandPosition);
                }
                return video_id;
            }
            if (url.hostname === 'youtu.be') {
                return url.pathname.split('/')[1];
            }
            return '';
        };
        AngularEmbedVideoService.prototype.detectDailymotion = function (url) {
            if (url.hostname.indexOf('dailymotion.com') > -1) {
                return url.pathname.split('/')[2].split('_')[0];
            }
            if (url.hostname === 'dai.ly') {
                return url.pathname.split('/')[1];
            }
            return '';
        };
        return AngularEmbedVideoService;
    }());
    AngularEmbedVideoService.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoService, deps: [{ token: i1__namespace.HttpClient }, { token: i2__namespace.DomSanitizer }], target: i0__namespace.ɵɵFactoryTarget.Injectable });
    AngularEmbedVideoService.ɵprov = i0__namespace.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoService, providedIn: 'root' });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoService, decorators: [{
                type: i0.Injectable,
                args: [{
                        providedIn: 'root'
                    }]
            }], ctorParameters: function () { return [{ type: i1__namespace.HttpClient }, { type: i2__namespace.DomSanitizer }]; } });

    var AngularEmbedVideoModule = /** @class */ (function () {
        function AngularEmbedVideoModule() {
        }
        return AngularEmbedVideoModule;
    }());
    AngularEmbedVideoModule.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoModule, deps: [], target: i0__namespace.ɵɵFactoryTarget.NgModule });
    AngularEmbedVideoModule.ɵmod = i0__namespace.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoModule, imports: [i1.HttpClientModule] });
    AngularEmbedVideoModule.ɵinj = i0__namespace.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoModule, providers: [AngularEmbedVideoService], imports: [[i1.HttpClientModule]] });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.1.3", ngImport: i0__namespace, type: AngularEmbedVideoModule, decorators: [{
                type: i0.NgModule,
                args: [{
                        imports: [i1.HttpClientModule],
                        providers: [AngularEmbedVideoService]
                    }]
            }] });

    /*
     * Public API Surface of angular-embed-video
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.AngularEmbedVideoModule = AngularEmbedVideoModule;
    exports.AngularEmbedVideoService = AngularEmbedVideoService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-embed-video.umd.js.map
